@@ -1,14 +1,15 @@
 # Copyright 2009 by Tiago Antao <tiagoantao@gmail.com>.  All rights reserved.
-# This code is part of the Biopython distribution and governed by its
-# license.  Please see the LICENSE file that should have been included
-# as part of this package.
+#
+# This file is part of the Biopython distribution and governed by your
+# choice of the "Biopython License Agreement" or the "BSD 3-Clause License".
+# Please see the LICENSE file that should have been included as part of this
+# package.
 
 """Module to control GenePop."""
 
 import os
 import re
 import shutil
-import sys
 import tempfile
 
 from Bio.Application import AbstractCommandline, _Argument
@@ -63,11 +64,11 @@ def _read_table(f, funs):
     while "===" not in line and "---" not in line and line != "":
         toks = [x for x in line.split(" ") if x != ""]
         parts = []
-        for i in range(len(toks)):
+        for i, tok in enumerate(toks):
             try:
-                parts.append(funs[i](toks[i]))
+                parts.append(funs[i](tok))
             except ValueError:
-                parts.append(toks[i])  # Could not cast
+                parts.append(tok)  # Could not cast
         table.append(tuple(parts))
         line = f.readline().rstrip()
     return table
@@ -97,8 +98,8 @@ def _read_headed_triangle_matrix(f):
                 clean_vals.append(_gp_float(val))
             except ValueError:
                 clean_vals.append(None)
-        for col_pop in range(len(clean_vals)):
-            matrix[(line_pop + 1, col_pop)] = clean_vals[col_pop]
+        for col_pop, clean_val in enumerate(clean_vals):
+            matrix[(line_pop + 1, col_pop)] = clean_val
     return matrix
 
 
@@ -132,7 +133,7 @@ def _hw_func(stream, is_locus, has_fisher=False):
     raise StopIteration
 
 
-class _FileIterator(object):
+class _FileIterator:
     """Return an iterator which crawls over a stream of lines with a function (PRIVATE).
 
     The generator function is expected to yield a tuple, while
@@ -159,19 +160,9 @@ class _FileIterator(object):
     def __next__(self):
         return self.func(self)
 
-    if sys.version_info[0] < 3:
-
-        def next(self):
-            """Return next item, a Python 2 style alias for Python 3 style __next__ method."""
-            return self.__next__()
-
     def __del__(self):
         self.stream.close()
-        try:
-            os.remove(self.fname)
-        except OSError:
-            # Jython seems to call the iterator twice
-            pass
+        os.remove(self.fname)
 
 
 class _GenePopCommandline(AbstractCommandline):
@@ -180,7 +171,7 @@ class _GenePopCommandline(AbstractCommandline):
     def __init__(self, genepop_dir=None, cmd="Genepop", **kwargs):
         self.parameters = [
             _Argument(["command"], "GenePop option to be called", is_required=True),
-            _Argument(["mode"], "Should allways be batch", is_required=True),
+            _Argument(["mode"], "Should always be batch", is_required=True),
             _Argument(["input"], "Input file", is_required=True),
             _Argument(["Dememorization"], "Dememorization step"),
             _Argument(["BatchNumber"], "Number of MCMC batches"),
@@ -207,7 +198,7 @@ class _GenePopCommandline(AbstractCommandline):
         self.set_parameter("input", "InputFile=" + fname)
 
 
-class GenePopController(object):
+class GenePopController:
     """Define a class to interface with the GenePop program."""
 
     def __init__(self, genepop_dir=None):
@@ -247,7 +238,6 @@ class GenePopController(object):
         self.controller()  # checks error level is zero
         os.chdir(cwd)
         shutil.rmtree(temp_dir)
-        return
 
     def _test_pop_hz_both(
         self,
